difflicious

package difflicious

Members list

Type members

Classlikes

final class AlwaysIgnoreDiffer[T] extends Differ[T]

A Differ that always return an Ignored result. Useful when you can't really diff a type

A Differ that always return an Ignored result. Useful when you can't really diff a type

Attributes

Supertypes
trait Differ[T]
trait ConfigureMethods[T]
class Object
trait Matchable
class Any
sealed trait ConfigureError extends Throwable

Attributes

Companion
object
Supertypes
class Throwable
trait Serializable
class Object
trait Matchable
class Any
Known subtypes

Attributes

Companion
trait
Supertypes
trait Sum
trait Mirror
class Object
trait Matchable
class Any
Self type
sealed trait ConfigureOp

The configuration change operation we want to perform on a differ. For example we might want to:

The configuration change operation we want to perform on a differ. For example we might want to:

  • Mark the current differ as ignored so its comparison never fails
  • Change a Differ for Seq to pair by a field instead of index

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
Known subtypes
trait PairBy[A]
class ByFunc[A, B]
object Index
class SetIgnored
class TransformDiffer[T]
object ConfigureOp

Attributes

Companion
trait
Supertypes
trait Sum
trait Mirror
class Object
trait Matchable
class Any
Self type
final case class ConfigurePath(resolvedSteps: Vector[String], unresolvedSteps: List[String])

Attributes

Companion
object
Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
object ConfigurePath

Attributes

Companion
class
Supertypes
trait Product
trait Mirror
class Object
trait Matchable
class Any
Self type
object DiffInput

Attributes

Companion
trait
Supertypes
trait Sum
trait Mirror
class Object
trait Matchable
class Any
Self type
DiffInput.type
sealed trait DiffInput[A]

Input for diffing. We can either have both the left side (obtained) and right side (expected), or just one side.

Input for diffing. We can either have both the left side (obtained) and right side (expected), or just one side.

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
Known subtypes
class Both[A]
class ExpectedOnly[A]
class ObtainedOnly[A]
sealed trait DiffResult

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
Known subtypes
class ListResult
class MapResult
class RecordResult
trait ValueResult
class Both
class ExpectedOnly
class ObtainedOnly
Show all
object DiffResult

Attributes

Companion
trait
Supertypes
trait Sum
trait Mirror
class Object
trait Matchable
class Any
Self type
DiffResult.type

Attributes

Supertypes
class Object
trait Matchable
class Any
Self type

Attributes

Companion
trait
Supertypes
trait DifferGen
class Object
trait Matchable
class Any
Show all
Self type
Differ.type
trait Differ[T] extends ConfigureMethods[T]

Attributes

Companion
object
Supertypes
trait ConfigureMethods[T]
class Object
trait Matchable
class Any
Known subtypes
class LazyDiffer[T]
class MapDiffer[M, K, V]
class OneOfDiffer[A]
class ProductDiffer[T]
class RecordDiffer[T]
class SeqDiffer[F, A]
class SetDiffer[F, A]
trait ValueDiffer[T]
class EqualsDiffer[T]
class NumericDiffer[T]
class TransformedDiffer[T, U]
Show all
trait DifferGen

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object Differ

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object Differ
final class DifferSubTypeRelationship[A, B](val path: String)

Attributes

Supertypes
class Object
trait Matchable
class Any

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object Differ

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object Differ
sealed trait PairType

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
Known subtypes
object Both
object ExpectedOnly
object ObtainedOnly
object PairType

Attributes

Companion
trait
Supertypes
trait Sum
trait Mirror
class Object
trait Matchable
class Any
Self type
PairType.type
object debug

Attributes

Supertypes
class Object
trait Matchable
class Any
Self type
debug.type

Attributes

Supertypes
trait ToPairByOps
trait ToSubTypeOp
class Object
trait Matchable
class Any
Show all
Self type
implicits.type