ListResult

difflicious.DiffResult.ListResult
final case class ListResult(typeName: SomeTypeName, items: Vector[DiffResult], pairType: PairType, isIgnored: Boolean, isOk: Boolean) extends DiffResult

Attributes

Graph
Supertypes
trait Serializable
trait Product
trait Equals
trait DiffResult
class Object
trait Matchable
class Any
Show all

Members list

Value members

Inherited methods

def productElementNames: Iterator[String]

An iterator over the names of all the elements of this product.

An iterator over the names of all the elements of this product.

Attributes

Inherited from:
Product
def productIterator: Iterator[Any]

An iterator over all the elements of this product.

An iterator over all the elements of this product.

Attributes

Returns

in the default implementation, an Iterator[Any]

Inherited from:
Product