difflicious.differ
Members list
Type members
Classlikes
Differ where the two values are compared by using the equals method. If the two values aren't equal, then we use the provided valueToString function to output the diagnostic output.
Differ where the two values are compared by using the equals method. If the two values aren't equal, then we use the provided valueToString function to output the diagnostic output.
Attributes
- Supertypes
-
trait ValueDiffer[T]trait Differ[T]trait ConfigureMethods[T]class Objecttrait Matchableclass AnyShow all
A wrapper over another Differ that lazily initializes it when needed. Used to break self-referencing cycles such as recursive data structures
A wrapper over another Differ that lazily initializes it when needed. Used to break self-referencing cycles such as recursive data structures
Attributes
- Companion
- object
- Supertypes
Attributes
- Companion
- class
- Supertypes
-
class Objecttrait Matchableclass Any
- Self type
-
LazyDiffer.type
Attributes
- Companion
- object
- Supertypes
Attributes
- Companion
- class
- Supertypes
-
class Objecttrait Matchableclass Any
- Self type
-
NumericDiffer.type
Attributes
- Companion
- object
- Supertypes
-
trait ValueDiffer[T]trait Differ[T]trait ConfigureMethods[T]class Objecttrait Matchableclass AnyShow all
Attributes
- Companion
- object
- Supertypes
Attributes
- Companion
- class
- Supertypes
-
class Objecttrait Matchableclass Any
- Self type
-
OneOfDiffer.type
A differ for product data structures such as tuples and case classes.
A differ for product data structures such as tuples and case classes.
Attributes
- Supertypes
A differ for a record-like data structure such as tuple or case classes.
A differ for a record-like data structure such as tuple or case classes.
Attributes
- Supertypes
Attributes
- Companion
- object
- Supertypes
Attributes
- Companion
- object
- Supertypes
A Differ that transforms any input of diff method and pass it to its underlying Differ. See ValueDiffer.contramap
A Differ that transforms any input of diff method and pass it to its underlying Differ. See ValueDiffer.contramap
Attributes
- Supertypes
-
trait ValueDiffer[T]trait Differ[T]trait ConfigureMethods[T]class Objecttrait Matchableclass AnyShow all
Differ where the error diagnostic output is just string values. Simple types where a string representation is enough for diagnostics purposes should use Differ.useEquals (EqualsDiffer is a subtype of this trait). For example, Differ for Int, String, java.time.Instant are all ValueDiffers.
Differ where the error diagnostic output is just string values. Simple types where a string representation is enough for diagnostics purposes should use Differ.useEquals (EqualsDiffer is a subtype of this trait). For example, Differ for Int, String, java.time.Instant are all ValueDiffers.
This trait also provide an extra contramap method which makes it easy to write instances for newtypes / opaque types.
Attributes
- Supertypes
- Known subtypes