difflicious.utils

Members list

Type members

Classlikes

object Eachable extends EachableInstances

Attributes

Supertypes
class Object
trait Matchable
class Any
Self type
Eachable.type
trait Eachable0[A, Element]

Attributes

Supertypes
class Object
trait Matchable
class Any
trait Eachable1[F[_]]

Attributes

Supertypes
class Object
trait Matchable
class Any
trait Eachable2[F[_, _]]

Attributes

Supertypes
class Object
trait Matchable
class Any

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object Eachable
object implicits
trait MapLike[M[_, _]]

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
object MapLike

Attributes

Companion
trait
Supertypes
class Object
trait Matchable
class Any
Self type
MapLike.type
trait Pairable[F[_]]

A marker typeclass for some container that we can use pairBy when diffing

A marker typeclass for some container that we can use pairBy when diffing

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
object Pairable extends PairableInstances

Attributes

Companion
trait
Supertypes
class Object
trait Matchable
class Any
Self type
Pairable.type

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object Pairable
object implicits
trait SeqLike[F[_]]

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
object SeqLike

Attributes

Companion
trait
Supertypes
class Object
trait Matchable
class Any
Self type
SeqLike.type
trait SetLike[F[_]]

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
object SetLike

Attributes

Companion
trait
Supertypes
class Object
trait Matchable
class Any
Self type
SetLike.type
trait SubTypeOp[A]

Attributes

Supertypes
class Object
trait Matchable
class Any

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object implicits
trait ToSubTypeOp

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object implicits
object TypeName extends TypeNamePlatform

Attributes

Companion
class
Supertypes
trait Product
trait Mirror
class Object
trait Matchable
class Any
Show all
Self type
TypeName.type
final case class TypeName[A](long: String, short: String, typeArguments: List[TypeName[_]])

Attributes

Companion
object
Supertypes
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all

Attributes

Supertypes
class Object
trait Matchable
class Any
Known subtypes
object TypeName